@@ -29,7 +29,7 @@ public:
 	
 	int findPeriod() const;
 	
-	QString exportUnit() const;
+	QString exportUnit() const Q_DECL_OVERRIDE;
 
 };
 
